@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2017 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -273,7 +273,7 @@ class Keithley2400(Instrument, KeithleyBuffer):
         :param auto_range: Enables auto_range if True, else uses the set resistance
         """
         log.info("%s is measuring resistance." % self.name)
-        self.write(":SENS:FUNC RES;"
+        self.write(":SENS:FUNC 'RES';"
                    ":SENS:RES:MODE MAN;"
                    ":SENS:RES:NPLC %f;:FORM:ELEM RES;" % nplc)
         if auto_range:
