@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2016 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,8 @@
 #
 
 from pymeasure.instruments import Instrument, discreteTruncate
-from pymeasure.instruments.validators import strict_discrete_set, truncated_discrete_set
+from pymeasure.instruments.validators import strict_discrete_set, \
+    truncated_discrete_set, truncated_range
 
 import numpy as np
 import time
@@ -125,6 +126,85 @@ class SR830(Instrument):
         values=FILTER_SLOPES,
         map_values=True
     )
+    harmonic = Instrument.control(
+        "HARM?", "HARM%d",
+        """ An integer property that controls the harmonic that is measured.
+        Allowed values are 1 to 19999. Can be set. """,
+        validator=strict_discrete_set,
+        values=range(1, 20000),
+    )
+
+    aux_out_1 = Instrument.control(
+        "AUXV?1;", "AUXV1,%f;",
+        """ A floating point property that controls the output of Aux output 1 in
+        Volts, taking values between -10.5 V and +10.5 V.
+        This property can be set.""",
+        validator=truncated_range,
+        values=[-10.5, 10.5]
+    )
+    # For consistency with other lock-in instrument classes
+    dac1 = aux_out_1
+
+    aux_out_2 = Instrument.control(
+        "AUXV?2;", "AUXV2,%f;",
+        """ A floating point property that controls the output of Aux output 2 in
+        Volts, taking values between -10.5 V and +10.5 V.
+        This property can be set.""",
+        validator=truncated_range,
+        values=[-10.5, 10.5]
+    )
+    # For consistency with other lock-in instrument classes
+    dac2 = aux_out_2
+
+    aux_out_3 = Instrument.control(
+        "AUXV?3;", "AUXV3,%f;",
+        """ A floating point property that controls the output of Aux output 3 in
+        Volts, taking values between -10.5 V and +10.5 V.
+        This property can be set.""",
+        validator=truncated_range,
+        values=[-10.5, 10.5]
+    )
+    # For consistency with other lock-in instrument classes
+    dac3 = aux_out_3
+
+    aux_out_4 = Instrument.control(
+        "AUXV?4;", "AUXV4,%f;",
+        """ A floating point property that controls the output of Aux output 4 in
+        Volts, taking values between -10.5 V and +10.5 V.
+        This property can be set.""",
+        validator=truncated_range,
+        values=[-10.5, 10.5]
+    )
+    # For consistency with other lock-in instrument classes
+    dac4 = aux_out_4
+
+    aux_in_1 = Instrument.measurement(
+        "OAUX?1;",
+        """ Reads the Aux input 1 value in Volts with 1/3 mV resolution. """
+    )
+    # For consistency with other lock-in instrument classes
+    adc1 = aux_in_1
+
+    aux_in_2 = Instrument.measurement(
+        "OAUX?2;",
+        """ Reads the Aux input 2 value in Volts with 1/3 mV resolution. """
+    )
+    # For consistency with other lock-in instrument classes
+    adc2 = aux_in_2
+
+    aux_in_3 = Instrument.measurement(
+        "OAUX?3;",
+        """ Reads the Aux input 3 value in Volts with 1/3 mV resolution. """
+    )
+    # For consistency with other lock-in instrument classes
+    adc3 = aux_in_3
+
+    aux_in_4 = Instrument.measurement(
+        "OAUX?4;",
+        """ Reads the Aux input 4 value in Volts with 1/3 mV resolution. """
+    )
+    # For consistency with other lock-in instrument classes
+    adc4 = aux_in_4
 
     def __init__(self, resourceName, **kwargs):
         super(SR830, self).__init__(
