@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2017 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -32,13 +32,14 @@ def strict_range(value, values):
     :param values: A range of values (range, list, etc.)
     :raises: ValueError if the value is out of the range
     """
-    if value <= max(values) and value >= min(values):
+    if min(values) <= value <= max(values):
         return value
     else:
         raise ValueError('Value of {:g} is not in range [{:g},{:g}]'.format(
             value, min(values), max(values)
         ))
 
+
 def strict_discrete_set(value, values):
     """ Provides a validator function that returns the value
     if it is in the discrete set. Otherwise it raises a ValueError.
@@ -54,6 +55,7 @@ def strict_discrete_set(value, values):
             value, values
         ))
 
+
 def truncated_range(value, values):
     """ Provides a validator function that returns the value
     if it is in the range. Otherwise it returns the closest
@@ -62,13 +64,39 @@ def truncated_range(value, values):
     :param value: A value to test
     :param values: A set of values that are valid
     """
-    if value <= max(values) and value >= min(values):
+    if min(values) <= value <= max(values):
         return value
     elif value > max(values):
         return max(values)
     else:
         return min(values)
 
+
+def modular_range(value, values):
+    """ Provides a validator function that returns the value
+    if it is in the range. Otherwise it returns the value,
+    modulo the max of the range.
+
+    :param value: a value to test
+    :param values: A set of values that are valid
+    """
+    return value % max(values)
+
+
+def modular_range_bidirectional(value, values):
+    """ Provides a validator function that returns the value
+    if it is in the range. Otherwise it returns the value,
+    modulo the max of the range. Allows negative values.
+
+    :param value: a value to test
+    :param values: A set of values that are valid
+    """
+    if value > 0:
+        return value % max(values)
+    else:
+        return -1 * (abs(value) % max(values))
+
+
 def truncated_discrete_set(value, values):
     """ Provides a validator function that returns the value
     if it is in the discrete set. Otherwise, it returns the smallest
@@ -83,13 +111,16 @@ def truncated_discrete_set(value, values):
     for v in values:
         if value <= v:
             return v
-    return v
+
+    return values[-1]
+
 
 def joined_validators(*validators):
     """ Join a list of validators together as a single.  Expects a list of validator functions and values.
 
     :param validators: an iterable of other validators
     """
+
     def validate(value, values):
         for validator, vals in zip(validators, values):
             try:
@@ -97,4 +128,18 @@ def joined_validators(*validators):
             except (ValueError, TypeError):
                 pass
         raise ValueError("Value of {} not in chained validator set".format(value))
+
     return validate
+
+
+def discreteTruncate(number, discreteSet):
+    """ Truncates the number to the closest element in the positive discrete set.
+    Returns False if the number is larger than the maximum value or negative.
+    """
+    if number < 0:
+        return False
+    discreteSet.sort()
+    for item in discreteSet:
+        if number <= item:
+            return item
+    return False
